.. _reference:

#########
Reference
#########

Technical reference material.

.. toctree::
    :maxdepth: 1

    api_references
    cli
    configuration
    fields
    navigation
    pages
    permissions
    placeholders
    plugins
    sitemaps
    templatetags
    titles
    toolbar
    wizards
